@@ -77,7 +77,7 @@ class SQ_SlideShowListing;
 
 class KSquirrel : public TDEMainWindow, public DCOPObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
