@@ -996,7 +996,7 @@ void SQ_GLWidget::initAccelsAndMenu()
 
 void SQ_GLWidget::slotAccelActivated()
 {
-    TDEAction *accel = static_cast<TDEAction *>(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME *>(sender())));
+    TDEAction *accel = static_cast<TDEAction *>(const_cast<TQObject *>(sender()));
 
     TDEShortcut ks = accel->shortcut();
 
