@@ -118,7 +118,7 @@ void SQ_ImageProperties::setFileParams()
         TQObjectList *ch = const_cast<TQObjectList *>(kew1->children());
         for(TQObjectList::iterator it = ch->begin();it != ch->end();++it)
         {
-            if((*it)->inherits(TQLISTVIEW_OBJECT_NAME_STRING))
+            if((*it)->inherits("TQListView"))
             {
                 TQListView *l = dynamic_cast<TQListView *>(*it);
                 TQWidget   *w = tabWidget->page(3);
