@@ -73,7 +73,7 @@ SQ_PreviewWidget::SQ_PreviewWidget(TQWidget *parent, const char *name)
     multi_pix = SQ_IconLoader::instance()->loadIcon("application-vnd.tde.tdemultiple", TDEIcon::Desktop, TDEIcon::SizeSmall);
 
     setMinimumHeight(20);
-    setFocusPolicy(TQ_WheelFocus);
+    setFocusPolicy(TQWidget::WheelFocus);
 }
 
 SQ_PreviewWidget::~SQ_PreviewWidget()
@@ -181,7 +181,7 @@ bool SQ_PreviewWidget::fit()
     {
         small = new TQImage();
 
-        *small = SQ_Utils::scale(*all, width(), height(), SQ_Utils::SMOOTH_FAST, TQ_ScaleMin);
+        *small = SQ_Utils::scale(*all, width(), height(), SQ_Utils::SMOOTH_FAST, TQImage::ScaleMin);
     }
 
     return true;
