@@ -97,7 +97,7 @@ void SQ_FileDetailView::slotShowToolTip(TQListViewItem *item)
 
 bool SQ_FileDetailView::eventFilter(TQObject *o, TQEvent *e)
 {
-    if(TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(viewport()) || TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this))
+    if(o == viewport() || o == this)
     {
         int type = e->type();
 
