@@ -75,7 +75,7 @@ void SQ_GLView::createContent()
     m_tabbar->setHoverCloseButton(m_tabsclose);
     m_tabbar->setHoverCloseButtonDelayed(false);
     m_tabbar->setMouseTracking(true);
-    m_tabbar->setFocusPolicy(TQ_NoFocus);
+    m_tabbar->setFocusPolicy(TQWidget::NoFocus);
 
     box->setStretchFactor(m_toolbar, 1);
 
@@ -150,7 +150,7 @@ void SQ_GLView::closeEvent(TQCloseEvent *e)
 
 bool SQ_GLView::eventFilter(TQObject *watched, TQEvent *e)
 {
-    if(TQT_BASE_OBJECT(watched) == TQT_BASE_OBJECT(this))
+    if(watched == this)
     {
         // stop animation, if SQ_GLView is hidden (animation becomes useless)
         if(/*e->type() == TQEvent::WindowDeactivate || */e->type() == TQEvent::Hide)
